@@ -1,5 +1,5 @@
 /*
- * $Id: appmenu.c,v 1.21 2002/01/02 15:36:03 tal197 Exp $
+ * $Id: appmenu.c,v 1.22 2002/01/30 13:08:59 tal197 Exp $
  *
  * ROX-Filer, filer for the ROX desktop project
  * Copyright (C) 2002, the ROX-Filer team.
@@ -185,7 +185,7 @@ static GtkWidget *create_menu_item(xmlNode *node)
 		label = g_strdup(_("<missing label>"));
 	item = gtk_menu_item_new_with_label(label);
 #ifdef GTK2
-	_gtk_widget_set_accel_path(item, NULL, NULL);
+	gtk_widget_set_accel_path(item, NULL, NULL);
 #else
 	gtk_widget_lock_accelerators(item);
 #endif
