@@ -1,5 +1,5 @@
 /*
- * $Id: collection.h,v 1.20 2001/06/28 16:00:48 tal197 Exp $
+ * $Id: collection.h,v 1.27 2001/12/26 20:33:21 tal197 Exp $
  *
  * The collection widget provides an area for displaying a collection of
  * objects (such as files). It allows the user to choose a selection of
@@ -36,9 +36,7 @@ enum
 };
 
 
-typedef struct _Collection       Collection;
 typedef struct _CollectionClass  CollectionClass;
-typedef struct _CollectionItem   CollectionItem;
 typedef void (*CollectionDrawFunc)(GtkWidget *widget,
 			     	  CollectionItem *item,
 			     	  GdkRectangle *area,
@@ -48,10 +46,13 @@ typedef gboolean (*CollectionTestFunc)( Collection *collection,
 			       		CollectionItem *item,
 			       		int width, int height,
 					gpointer user_data);
+typedef void (*CollectionFreeFunc)(Collection *collection,
+			     	   CollectionItem *item);
 
 struct _CollectionItem
 {
 	gpointer	data;
+	gpointer	view_data;
 	gboolean	selected;
 };
 
@@ -59,13 +60,20 @@ struct _Collection
 {
 	GtkWidget 	parent_widget;
 
+	/* For gtk+-1.2, the adjustment is used for redrawing in the right
+	 * place. With 2.0, the collection is in a Viewport, and this is
+	 * used only to force scrolling, etc.
+	 */
 	GtkAdjustment	*vadj;
+#ifndef GTK2
 	guint		last_scroll;	/* Current/previous scroll value */
+	int		paint_level;	/* Complete redraw on next paint? */
+#endif
 
 	CollectionDrawFunc draw_item;
 	CollectionTestFunc test_point;
+	CollectionFreeFunc free_item;
 	gpointer	cb_user_data;	/* Passed to above two functions */
-	int		paint_level;	/* Complete redraw on next paint? */
 	GdkGC		*bg_gc;		/* NULL unless pixmap background */
 	
 	gboolean	lasso_box;	/* Is the box drawn? */
@@ -77,6 +85,7 @@ struct _Collection
 	gint		cursor_item;		/* -1 if not shown */
 	gint		cursor_item_old;	/* May be -1 */
 	gint		wink_item;		/* -1 if not active */
+	gint		wink_on_map;		/* -1 if not waiting for map */
 	gint		winks_left;		/* Flashes in this wink op */
 	gint		wink_timeout;
 	guint		columns;
@@ -104,17 +113,20 @@ struct _CollectionClass
 					gint		time);
 };
 
-guint   collection_get_type   		(void);
-GtkWidget *collection_new          	(GtkAdjustment *vadj);
+GtkType collection_get_type   		(void);
+GtkWidget *collection_new		(void);
 void    collection_clear           	(Collection *collection);
 void	collection_clear_except		(Collection *collection, gint item);
-gint    collection_insert          	(Collection *collection, gpointer data);
+gint	collection_insert		(Collection *collection,
+					 gpointer data,
+					 gpointer view);
 void    collection_remove          	(Collection *collection, gint item);
 void    collection_unselect_item	(Collection *collection, gint item);
 void    collection_select_item		(Collection *collection, gint item);
 void 	collection_toggle_item		(Collection *collection, gint item);
 void 	collection_select_all		(Collection *collection);
 void 	collection_clear_selection	(Collection *collection);
+void	collection_invert_selection	(Collection *collection);
 void	collection_draw_item		(Collection *collection, gint item,
 					 gboolean blank);
 void 	collection_set_functions	(Collection *collection,
