@@ -1,5 +1,5 @@
 /*
- * $Id: filer.c,v 1.242 2002/01/21 17:03:51 tal197 Exp $
+ * $Id: filer.c,v 1.246 2002/02/12 15:54:08 tal197 Exp $
  *
  * ROX-Filer, filer for the ROX desktop project
  * Copyright (C) 2002, the ROX-Filer team.
@@ -230,6 +230,8 @@ static void filer_window_set_size(FilerWindow *filer_window,
 	
 	if (o_toolbar != TOOLBAR_NONE)
 		h += filer_window->toolbar_frame->allocation.height;
+	if (filer_window->message)
+		h += filer_window->message->allocation.height;
 
 	if (GTK_WIDGET_VISIBLE(filer_window->window))
 	{
@@ -309,6 +311,8 @@ static void filer_size_for(FilerWindow *filer_window,
 	 */
 	if (o_toolbar != TOOLBAR_NONE)
 		t = filer_window->toolbar_frame->allocation.height;
+	if (filer_window->message)
+		t += filer_window->message->allocation.height;
 	if (GTK_WIDGET_VISIBLE(filer_window->minibuffer_area))
 	{
 		GtkRequisition req;
@@ -924,16 +928,32 @@ static void group_save(FilerWindow *filer_window, char *name)
 			NULL, "group", NULL);
 	xmlSetProp(group, "name", name);
 
+#ifdef GTK2
 	xmlNewChild(group, NULL, "directory", filer_window->path);
+#else
+	{
+		gchar *u8_path;
+		u8_path = to_utf8(filer_window->path);
+		xmlNewChild(group, NULL, "directory", u8_path);
+		g_free(u8_path);
+	}
+#endif
 
 	for (i = 0; i < collection->number_of_items; i++)
 	{
 		DirItem *item = (DirItem *) collection->items[i].data;
+		gchar	*u8_leaf = item->leafname;
 		
 		if (!collection->items[i].selected)
 			continue;
 
-		xmlNewChild(group, NULL, "item", item->leafname);
+#ifdef GTK2
+		xmlNewChild(group, NULL, "item", u8_leaf);
+#else
+		u8_leaf = to_utf8(u8_leaf);
+		xmlNewChild(group, NULL, "item", u8_leaf);
+		g_free(u8_leaf);
+#endif
 	}
 
 	save_path = choices_find_path_save("Groups.xml", PROJECT, TRUE);
@@ -968,6 +988,14 @@ static void group_restore(FilerWindow *filer_window, char *name)
 	path = xmlNodeListGetString(groups->doc, node->xmlChildrenNode, 1);
 	g_return_if_fail(path != NULL);
 
+#ifndef GTK2
+	{
+		gchar *old = path;
+		path = from_utf8(old);
+		g_free(old);
+	}
+#endif
+
 	if (strcmp(path, filer_window->path) != 0)
 		filer_change_to(filer_window, path, NULL);
 	g_free(path);
@@ -995,7 +1023,15 @@ static void group_restore(FilerWindow *filer_window, char *name)
 		if (!leaf)
 			g_warning("Missing leafname!\n");
 		else
+		{
+#ifdef GTK2
 			g_hash_table_insert(in_group, leaf, filer_window);
+#else
+			g_hash_table_insert(in_group, from_utf8(leaf),
+								filer_window);
+			g_free(leaf);
+#endif
+		}
 	}
 	
 	for (j = 0; j < n; j++)
@@ -1308,6 +1344,7 @@ FilerWindow *filer_opendir(char *path, FilerWindow *src_win)
 #endif
 
 	filer_window = g_new(FilerWindow, 1);
+	filer_window->message = NULL;
 	filer_window->minibuffer = NULL;
 	filer_window->minibuffer_label = NULL;
 	filer_window->minibuffer_area = NULL;
@@ -1452,18 +1489,6 @@ static void filer_add_widgets(FilerWindow *filer_window)
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, TRUE, 0);
 	
-	/* If there's a message that should go at the top of every
-	 * window (eg 'Running as root'), add it here.
-	 */
-	if (show_user_message)
-	{
-		GtkWidget *label;
-
-		label = gtk_label_new(show_user_message);
-		gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, TRUE, 0);
-		gtk_widget_show(label);
-	}
-
 	/* Create a frame for the toolbar, but don't show it unless we actually
 	 * have a toolbar.
 	 * (allows us to change the toolbar later)
@@ -1485,6 +1510,17 @@ static void filer_add_widgets(FilerWindow *filer_window)
 		gtk_widget_show_all(filer_window->toolbar_frame);
 	}
 
+	/* If there's a message that should be displayed in each window (eg
+	 * 'Running as root'), add it here.
+	 */
+	if (show_user_message)
+	{
+		filer_window->message = gtk_label_new(show_user_message);
+		gtk_box_pack_start(GTK_BOX(vbox), filer_window->message,
+				   FALSE, TRUE, 0);
+		gtk_widget_show(filer_window->message);
+	}
+
 	/* Now add the area for displaying the files.
 	 * If we've got Gtk+-2.0 then the collection is one huge window
 	 * that goes in a Viewport. Otherwise, the collection handles
