@@ -1,5 +1,5 @@
 /*
- * $Id: main.c,v 1.123 2002/01/20 16:42:29 tal197 Exp $
+ * $Id: main.c,v 1.124 2002/01/24 14:25:49 tal197 Exp $
  *
  * ROX-Filer, filer for the ROX desktop project
  * Copyright (C) 2002, the ROX-Filer team.
@@ -591,7 +591,7 @@ static void show_features(void)
 			_("Yes (using Gtk+-2.0)")
 #else
 # ifdef HAVE_ICONV_H
-			_("Yes (using libiconv)")
+			_("Yes")
 # else
 			_("No (needs libiconv or Gtk+-2.0)")
 # endif
