@@ -1,5 +1,5 @@
 /*
- * $Id: pixmaps.c,v 1.69 2002/01/23 12:21:45 tal197 Exp $
+ * $Id: pixmaps.c,v 1.70 2002/02/02 14:31:32 tal197 Exp $
  *
  * ROX-Filer, filer for the ROX desktop project
  * Copyright (C) 2002, the ROX-Filer team.
@@ -662,7 +662,7 @@ static void save_thumbnail(char *path, GdkPixbuf *full, MaskedPixmap *image)
 	to = g_string_new(home_dir);
 	g_string_append(to, "/.thumbnails");
 	mkdir(to->str, 0700);
-	g_string_append(to, "/96x96/");
+	g_string_append(to, "/normal/");
 	mkdir(to->str, 0700);
 	g_string_append(to, md5);
 	name_len = to->len + 4; /* Truncate to this length when renaming */
@@ -738,7 +738,7 @@ static GdkPixbuf *get_thumbnail_for(char *path)
 	md5 = md5_hash(uri);
 	g_free(uri);
 	
-	thumb_path = g_strdup_printf("%s/.thumbnails/96x96/%s.png",
+	thumb_path = g_strdup_printf("%s/.thumbnails/normal/%s.png",
 					home_dir, md5);
 	g_free(md5);
 
