@@ -1,5 +1,5 @@
 /*
- * $Id: support.c,v 1.71 2002/01/18 15:39:07 tal197 Exp $
+ * $Id: support.c,v 1.72 2002/01/30 17:02:12 tal197 Exp $
  *
  * ROX-Filer, filer for the ROX desktop project
  * Copyright (C) 2002, the ROX-Filer team.
@@ -1307,9 +1307,7 @@ gchar *icon_convert_path(gchar *path)
 	return retval;
 }
 
-/* Convert string 'src' from the current locale to UTF-8.
- * If conversion fails, try again using ISO8859-1 -> UTF-8.
- */
+/* Convert string 'src' from the current locale to UTF-8 */
 gchar *to_utf8(gchar *src)
 {
 	gchar *retval;
@@ -1318,10 +1316,8 @@ gchar *to_utf8(gchar *src)
 		return NULL;
 
 	retval = g_locale_to_utf8(src, -1, NULL, NULL, NULL);
-	if (retval)
-		return retval;
 
-	return g_convert(src, -1, "UTF-8", "ISO8859-1", NULL, NULL, NULL);
+	return retval ? retval : g_strdup(src);
 }
 
 /* Convert string 'src' to the current locale from UTF-8 */
